# -*- coding: utf-8 -*-
# @Time    : 2020/11/20 16:20
# @Author  : Navy

class ProxyAbuyun(object):
    def __init__(self, username, password):
        self.username = username
        self.password = password

    @property
    def proxy(self):
        # 代理服务器
        proxyHost = "http-dyn.abuyun.com"
        proxyPort = "9020"

        # 代理隧道验证信息
        proxyUser = self.username
        proxyPass = self.password
        proxyMeta = "http://%(user)s:%(pass)s@%(host)s:%(port)s" % {
            "host": proxyHost,
            "port": proxyPort,
            "user": proxyUser,
            "pass": proxyPass,
        }

        proxies = {
            "http": proxyMeta,
            "https": proxyMeta
        }
        return proxies



# -*- coding: utf-8 -*-
# @Time    : 2020/11/20 16:29
# @Author  : Navy

import setuptools

with open('README.md', 'r', encoding='utf-8') as f:
    long_description = f.read()

setuptools.setup(
    name="proxy_abuyun",
    version='1.0.2',
    author='navy',
    auther_email='haijun0422@gmail.com',
    description='proxy of abuyun',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='',
    packages=setuptools.find_packages(),
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Topic :: Database',
    ],
)
